.env
.htaccess
BUILD.md
CHANGELOG.md
CODE_OF_CONDUCT.md
Dockerfile
INSTALL.md
LICENSE
README.md
SECURITY.md
UPGRADE.md
app
docker
docker-compose.dev.yml
docker-compose.nginx.yml
docker-compose.phpmyadmin.yml
docker-compose.test.yml
docker-compose.yml
public
tests
vendor
writable